@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Client::5_0::Direct;
-$Search::Elasticsearch::Client::5_0::Direct::VERSION = '6.80';
-use Moo;
+$Search::Elasticsearch::Client::5_0::Direct::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Client::5_0::Direct::VERSION = '6.8001';use Moo;
 with 'Search::Elasticsearch::Client::5_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 
@@ -79,7 +80,7 @@ Search::Elasticsearch::Client::5_0::Direct - Thin client with full support for E
 
 =head1 VERSION
 
-version 6.80
+version 6.80_01
 
 =head1 SYNOPSIS
 
