@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Client::5_0::Direct::Indices;
-$Search::Elasticsearch::Client::5_0::Direct::Indices::VERSION = '6.80';
-use Moo;
+$Search::Elasticsearch::Client::5_0::Direct::Indices::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Client::5_0::Direct::Indices::VERSION = '6.8001';use Moo;
 with 'Search::Elasticsearch::Client::5_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('indices');
@@ -17,7 +18,7 @@ Search::Elasticsearch::Client::5_0::Direct::Indices - A client for running index
 
 =head1 VERSION
 
-version 6.80
+version 6.80_01
 
 =head1 DESCRIPTION
 
