@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Client::5_0::Direct::Ingest;
-$Search::Elasticsearch::Client::5_0::Direct::Ingest::VERSION = '6.80';
-use Moo;
+$Search::Elasticsearch::Client::5_0::Direct::Ingest::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Client::5_0::Direct::Ingest::VERSION = '6.8001';use Moo;
 with 'Search::Elasticsearch::Client::5_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('ingest');
@@ -17,7 +18,7 @@ Search::Elasticsearch::Client::5_0::Direct::Ingest - A client for accessing the
 
 =head1 VERSION
 
-version 6.80
+version 6.80_01
 
 =head1 DESCRIPTION
 
