@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Client::5_0::Role::Bulk;
-$Search::Elasticsearch::Client::5_0::Role::Bulk::VERSION = '6.80';
-use Moo::Role;
+$Search::Elasticsearch::Client::5_0::Role::Bulk::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Client::5_0::Role::Bulk::VERSION = '6.8001';use Moo::Role;
 requires 'add_action', 'flush';
 
 use Search::Elasticsearch::Util qw(parse_params throw);
@@ -274,7 +275,7 @@ Search::Elasticsearch::Client::5_0::Role::Bulk - Provides common functionality t
 
 =head1 VERSION
 
-version 6.80
+version 6.80_01
 
 =head1 AUTHOR
 
